useDynLib(SimTOST, .registration=TRUE)
importFrom(Rcpp, evalCpp)
exportPattern("^[[:alpha:]]+")
S3method(plot,simss)
S3method(print,simss)
export(sampleSize_Mielke)
export(sampleSize)
export(simParallelEndpoints)
export(get_par)
export(plot.simss)
importFrom(data.table,.SD)
